@@ -225,7 +225,8 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
     Saves Model at each end of the epoch when the best accuracy/loss is presented.
     """
     def __init__(self, best_metric=float('inf'), save_root="./", save_metric='val_loss',
-                metric_type="loss",file_name="my_model", enable=True, epoch=0, include_optimizer=False, save_func=None):
+                metric_type="loss",file_name="my_model", enable=True, epoch=0, include_optimizer=False, save_func=None,
+                 keep_only_recent=False, save_every=True):
         """
 
         Args:
@@ -250,6 +251,15 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
         self.include_optimizer = include_optimizer
         self.metric_type = metric_type
         self.save_func = save_func
+        self.keep_only_recent = keep_only_recent
+        self.save_every = save_every
+
+    def save_model(self, file_name):
+        if self.enable:
+            if self.save_func:
+                self.save_func(file_name, include_optimizer=self.include_optimizer)
+            else:
+                self.model.save(file_name, include_optimizer=self.include_optimizer)
 
     def on_epoch_end(self, epoch, logs=None):
         try:
@@ -260,29 +270,29 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
             if self.metric_type == "score":
                 a, b = b, a
 
-            if a < b:
+            file_name = '{}/{}_{:04d}_{}_{:03.2f}.h5'.format(self.save_root, self.file_name, epoch, self.save_metric, logs[self.save_metric])
+
+            if self.save_every:
+                self.save_model(file_name)
+            elif a < b:
                 p_file_list = glob.glob("{}/*.h5".format(self.save_root))
                 p_file_list = sorted(p_file_list, key=lambda x: x[-10:])
                 if self.metric_type == "loss":
                     p_file_list = p_file_list[::-1]
 
-                for i, file_path in enumerate(p_file_list):
-                    if i+1 == len(p_file_list):
-                        break
-                    try:
-                        os.remove(file_path)
-                    except:
-                        print("Error while deleting file : {}".format(file_path))
+                if self.keep_only_recent:
+                    for i, file_path in enumerate(p_file_list):
+                        if i+1 == len(p_file_list):
+                            break
+                        try:
+                            os.remove(file_path)
+                        except:
+                            print("Error while deleting file : {}".format(file_path))
 
-                file_name = '{}/{}_{:04d}_{}_{:03.2f}.h5'.format(self.save_root, self.file_name, epoch, self.save_metric, logs[self.save_metric])
                 print("\nBest score! saving the model to {} ...".format(file_name))
                 self.best_metric = logs[self.save_metric]
 
-                if self.enable:
-                    if self.save_func:
-                        self.save_func(file_name, include_optimizer=self.include_optimizer)
-                    else:
-                        self.model.save(file_name, include_optimizer=self.include_optimizer)
+                self.save_model(file_name)
         except Exception as e:
             print(e)
 
